==> nmail-php-patch-2.3.1-to-2.4.0.tgz: nmail/sdomain_del_ok.php <==
<?
require_once('include/global.php');
require_once('include/admin_lib.php');
include_once("include/file.php");
require_once('sadmin_conf.inc.php');

mail_server_check_limit();		// ϼ  Ȯ

// check
	if (!$_GET['d_no'])
		msg('ùٸ URL Ͽ ֽʽÿ');

	// ȸ Ҷ Ұ.
		// [2008-02-21] ϸ Ʈ ȸ 
		//$sql = "SELECT COUNT(*) FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "'";
		$sql = "SELECT COUNT(*) FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype IS NULL";
		$mbr_cnt = db_get_one($sql);
		if ($mbr_cnt > 0)
			msg("γ [".$mbr_cnt."] ȸ ϹǷ   ϴ.\\n\\nȸ   Ͻñ ٶϴ.");

// data
	// θ 
		$sql = "SELECT d_name FROM ".$TB['DOMAIN']." WHERE d_no='". $_GET['d_no'] . "'";
		$d_name = db_get_one($sql);

	// Խ
		$q = "SELECT ba_no FROM ".$TB['BOARD_ADMIN']." WHERE d_no='" . $_GET['d_no'] ."' ORDER BY ba_no";
		//echo $q;
		$ba = db_get_rows($q);
		for ($i=0; $i<sizeof($ba); $i++)
		{
			$ba_no = $ba[$i]['ba_no'];

			// file delete
				$upload_dir = $UPLOAD_DIR[BOARD] . "/" . $ba_no;		// ex) BOARD/1 => /xxxx/upload/BOARD/1/
				dir_del_all($upload_dir, false);

			// delete
				$q = "DELETE FROM ".$TB['BOARD_COMMENT']." WHERE ba_no='$ba_no'";
				//echo "<HR>" . $q;
				db_query($q);

				$q = "DELETE FROM ".$TB['BOARD']." WHERE ba_no='$ba_no'";
				//echo "<HR>" . $q;
				db_query($q);

				$q = "DELETE FROM ".$TB['BOARD_ADMIN']." WHERE ba_no='$ba_no' AND d_no='" . $_GET['d_no'] . "'";
				//echo "<HR>" . $q;
				db_query($q);
		}	// for()


	// 
		$sql = "DELETE FROM ".$TB['NOTICE']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// ȸ׷
		$sql = "DELETE FROM ".$TB['MEMBER_GROUP']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// ϸƮ
		$sql = "SELECT m_no FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype = 'M'";
		$ml_m_no = db_get_rows($sql, true);
		if (sizeof($ml_m_no) > 0)
		{			
			$sql = "DELETE FROM " . $TB['MAILING_LIST'] . " WHERE m_no IN (".implode(',', $ml_m_no['m_no']).")";
			db_query($sql);

			$sql = "DELETE FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype = 'M'";
			db_query($sql);

			// ϼ Ʈ ϼ λ ϰ.			
		}	// if()
	

	// ϵ
		require_once("include/webhard_lib.php");
		$sql = "SELECT ws_key FROM " . $TB['WEBHARD_SHARE'] . " WHERE d_no='". $_GET['d_no'] . "'";
		$ws = db_get_rows($sql);
		for ($i=0; $i<sizeof($ws); $i++)
		{
			$upload_dir = 'webhard/'.$d_name.'/share/'.$ws[$i]['ws_key'];
			webhard_folder_del($ws[$i]['ws_key'], $wfd_key=0, $upload_dir, $is_root_del=true, $m_no=0);
		}	// for()
		$sql = "DELETE FROM " . $TB['WEBHARD_SHARE'] . " WHERE d_no='". $_GET['d_no'] . "'";
		db_query($sql);
		dir_del_all('webhard/'.$d_name, false);


	// 뷮÷ 
		dir_del_all('bigfile/'.$d_name, false);

	
	// ΰ 
		dir_del_all('logo/'.$d_name, false);


	//  ؾ κ
	// 
		$m_mail_file_group = '0000';
		$mail_file_table = $G_SYS[PRE_FIX] . 'mail_file_' . $_GET['d_no'] . '_' . $m_mail_file_group;
		if ($G_SYS[DB] == 'oracle') 
		{
			$sql = "SELECT COUNT(*) FROM USER_OBJECTS WHERE OBJECT_NAME = '" . strtoupper($mail_file_table) . "' AND OBJECT_TYPE = 'TABLE'";
			db_query("DROP SEQUENCE sqc_".$mail_file_table);
		} else 
		{
			$sql = "SHOW TABLES LIKE '".$mail_file_table."'";
		}	// if()		
		$st = db_get_one($sql);
		if ($st)
		{
			$sql = "DROP TABLE ".$mail_file_table;
			db_query($sql);
		}	// if()


	// ȸʵ
		$sql = "DELETE FROM ".$TB['MEMBER_FIELD']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// Ͽ ó.
		require_once('include/admin_lib.php');
		domain_del($d_name);


	// 
		$sql = "
			DELETE
			FROM
				" . $TB['DOMAIN'] . "
			WHERE
				d_no='" . $_GET['d_no'] . "'
			";
		db_query($sql);

// end
	msg("Ǿϴ.", 0);
	movepage('sdomain_list.php?' . get_qs('d_no'));


require_once('include/global_end.php');
?>

==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/sdomain_del_ok.php <==
<?
require_once('include/global.php');
require_once('include/admin_lib.php');
include_once("include/file.php");
require_once('sadmin_conf.inc.php');

mail_server_check_limit();		// ϼ  Ȯ

// check
	if (!$_GET['d_no'])
		msg('ùٸ URL Ͽ ֽʽÿ');

	// ȸ Ҷ Ұ.
		// [2008-02-21] ϸ Ʈ ȸ 
		//$sql = "SELECT COUNT(*) FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "'";
		$sql = "SELECT COUNT(*) FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype IS NULL";
		$mbr_cnt = db_get_one($sql);
		if ($mbr_cnt > 0)
			msg("γ [".$mbr_cnt."] ȸ ϹǷ   ϴ.\\n\\nȸ   Ͻñ ٶϴ.");

// data
	// θ 
		$sql = "SELECT d_name FROM ".$TB['DOMAIN']." WHERE d_no='". $_GET['d_no'] . "'";
		$d_name = db_get_one($sql);

	// Խ
		$q = "SELECT ba_no FROM ".$TB['BOARD_ADMIN']." WHERE d_no='" . $_GET['d_no'] ."' ORDER BY ba_no";
		//echo $q;
		$ba = db_get_rows($q);
		for ($i=0; $i<sizeof($ba); $i++)
		{
			$ba_no = $ba[$i]['ba_no'];

			// file delete
				$upload_dir = $UPLOAD_DIR[BOARD] . "/" . $ba_no;		// ex) BOARD/1 => /xxxx/upload/BOARD/1/
				dir_del_all($upload_dir, false);

			// delete
				$q = "DELETE FROM ".$TB['BOARD_COMMENT']." WHERE ba_no='$ba_no'";
				//echo "<HR>" . $q;
				db_query($q);

				$q = "DELETE FROM ".$TB['BOARD']." WHERE ba_no='$ba_no'";
				//echo "<HR>" . $q;
				db_query($q);

				$q = "DELETE FROM ".$TB['BOARD_ADMIN']." WHERE ba_no='$ba_no' AND d_no='" . $_GET['d_no'] . "'";
				//echo "<HR>" . $q;
				db_query($q);
		}	// for()

		// [2011-01-05] ޴
		$q = "DELETE FROM ".$TB['BOARD_MENU']." WHERE d_no='" . $_GET['d_no'] . "'";
		//echo "<HR>" . $q;
		db_query($q);


	// 
		$sql = "DELETE FROM ".$TB['NOTICE']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// [2012-11-28] 
		$sql = "DELETE FROM ".$TB['DIARY']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// [2012-11-28] ּҷ
		$adg = db_get_rows("SELECT adg_no FROM " . $TB['ADDR_GROUP'] . " WHERE d_no='".$_GET['d_no']."'");
		for ($i=0; $i<sizeof($adg); $i++)
		{
			$q = "DELETE FROM " . $TB['ADDR'] . " WHERE adg_no='" . $adg[$i]['adg_no'] . "'";
			db_query($q);
		}	// for()


	// [2008-08-13] ȸ
		$sql = "DELETE FROM ".$TB['MEMBER_CLASS']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// [2008-08-13] ȸ - ϰ   .


	// ȸ
		$sql = "DELETE FROM ".$TB['MEMBER_GROUP']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// ϸƮ
		$sql = "SELECT m_no FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype = 'M'";
		$ml_m_no = db_get_rows($sql, true);
		if (sizeof($ml_m_no) > 0)
		{
			$sql = "DELETE FROM " . $TB['MAILING_LIST'] . " WHERE m_no IN (".implode(',', $ml_m_no['m_no']).")";
			db_query($sql);

			$sql = "DELETE FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype = 'M'";
			db_query($sql);

			// ϼ Ʈ ϼ λ ϰ.
		}	// if()


	// [2008-09-11] ϵ Guest 
		$sql = "DELETE FROM ".$TB['MEMBER']." WHERE d_no='". $_GET['d_no'] . "' AND m_usertype = 'W'";
		db_query($sql);


	// ϵ
		require_once("include/webhard_lib.php");
		$sql = "SELECT ws_key FROM " . $TB['WEBHARD_SHARE'] . " WHERE d_no='". $_GET['d_no'] . "'";
		$ws = db_get_rows($sql);
		for ($i=0; $i<sizeof($ws); $i++)
		{
			$upload_dir = 'webhard/'.$d_name.'/share/'.$ws[$i]['ws_key'];
			webhard_folder_del($ws[$i]['ws_key'], $wfd_key=0, $upload_dir, $is_root_del=true, $m_no=0);
		}	// for()
		$sql = "DELETE FROM " . $TB['WEBHARD_SHARE'] . " WHERE d_no='". $_GET['d_no'] . "'";
		db_query($sql);
		dir_del_all('webhard/'.$d_name, false);


	// 뷮÷ 
		dir_del_all('bigfile/'.$d_name, false);


	// ΰ 
		dir_del_all('logo/'.$d_name, false);


	//  ؾ κ
	// 
		for ($i=0; $i<=9999; $i++)
		{
			// [2012-11-28]
			//$m_mail_file_group = '0000';
			$m_mail_file_group = sprintf("%04d", $i);
			$mail_file_table = $G_SYS[PRE_FIX] . 'mail_file_' . $_GET['d_no'] . '_' . $m_mail_file_group;
			if ($G_SYS[DB] == 'oracle')
			{
				$sql = "SELECT COUNT(*) FROM USER_OBJECTS WHERE OBJECT_NAME = '" . strtoupper($mail_file_table) . "' AND OBJECT_TYPE = 'TABLE'";
				//db_query("DROP SEQUENCE sqc_".$mail_file_table);
			} else
			{
				$sql = "SHOW TABLES LIKE '".$mail_file_table."'";
			}	// if()
			$st = db_get_one($sql);
			if ($st)
			{
				// [2011-02-08] Oracle ȯ濡    
				if ($G_SYS[DB] == 'oracle')
				{
					db_query("DROP SEQUENCE sqc_".$mail_file_table);
				}	// if()
				$sql = "DROP TABLE ".$mail_file_table;
				db_query($sql);
			} else 
			{
				if ($m_mail_file_group != '0000')
					break;					
			}	// if()			
		}	// for()

	// ȸʵ
		$sql = "DELETE FROM ".$TB['MEMBER_FIELD']." WHERE d_no='".$_GET['d_no']."'";
		db_query($sql);


	// Ͽ ó.
		require_once('include/admin_lib.php');
		domain_del($d_name);


	// 
		$sql = "
			DELETE
			FROM
				" . $TB['DOMAIN'] . "
			WHERE
				d_no='" . $_GET['d_no'] . "'
			";
		db_query($sql);

// end
	msg("Ǿϴ.", 0);
	movepage('sdomain_list.php?' . get_qs('d_no'));


require_once('include/global_end.php');
?>
